==> bootstrap-core-1.0.59-sources.jar: com/turbospaces/cfg/TypedPropertyFactory.java <==
package com.turbospaces.cfg;

import java.math.BigDecimal;
import java.net.URL;
import java.time.Duration;
import java.time.LocalDate;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.regex.Pattern;

import com.google.common.collect.Range;
import com.netflix.archaius.api.Property;

import reactor.core.scheduler.Scheduler;
import reactor.util.retry.Retry;

public interface TypedPropertyFactory {
    ApplicationConfig cfg();
    boolean warnInconsistency(String... cfgs) throws Exception;
    Retry retry(Scheduler scheduler);

    Property<List<Integer>> listOfInts(String key);
    Property<List<Long>> listOfLongs(String key);
    Property<List<String>> listOfStrings(String key);
    Property<List<Double>> listOfDoubles(String key);
    Property<List<BigDecimal>> listOfBigDecimals(String key);
    Property<List<LocalDate>> listOfLocalDates(String key);
    Property<List<Pattern>> listOfPatterns(String key);

    Property<Map<String, Integer>> mapOfStringInts(String key);
    Property<Map<String, Long>> mapOfStringLongs(String key);
    Property<Map<String, String>> mapOfStringStrings(String key);
    Property<Map<String, Double>> mapOfStringDoubles(String key);
    Property<Map<String, BigDecimal>> mapOfStringBigDecimals(String key);

    Property<Set<Integer>> setOfInts(String key);
    Property<Set<Long>> setOfLongs(String key);
    Property<Set<String>> setOfStrings(String key);
    Property<Set<Double>> setOfDoubles(String key);
    Property<Set<BigDecimal>> setOfBigDecimals(String key);
    Property<Set<LocalDate>> setOfLocalDates(String key);
    Property<Set<Pattern>> setOfPatterns(String key);

    Property<Duration> rangeValue(String key, Duration defaultValue, Range<Duration> boundaries);

    void analyze(URL url) throws Exception; // ~ offline

    String externalIp();
}

==> bootstrap-core-1.0.60-sources.jar: com/turbospaces/cfg/TypedPropertyFactory.java <==
package com.turbospaces.cfg;

import java.math.BigDecimal;
import java.net.URL;
import java.time.Duration;
import java.time.LocalDate;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.regex.Pattern;

import com.google.common.collect.ImmutableMap;
import com.google.common.collect.Range;
import com.netflix.archaius.api.Property;

import reactor.core.scheduler.Scheduler;
import reactor.util.retry.Retry;

public interface TypedPropertyFactory {
    ApplicationConfig cfg();
    boolean warnInconsistency(String... cfgs) throws Exception;
    Retry retry(Scheduler scheduler);

    Property<List<Integer>> listOfInts(String key);
    Property<List<Long>> listOfLongs(String key);
    Property<List<String>> listOfStrings(String key);
    Property<List<Double>> listOfDoubles(String key);
    Property<List<BigDecimal>> listOfBigDecimals(String key);
    Property<List<LocalDate>> listOfLocalDates(String key);
    Property<List<Pattern>> listOfPatterns(String key);

    Property<Map<String, Integer>> mapOfStringInts(String key);
    Property<Map<String, Long>> mapOfStringLongs(String key);
    Property<Map<String, String>> mapOfStringStrings(String key);
    Property<Map<String, Double>> mapOfStringDoubles(String key);
    Property<Map<String, BigDecimal>> mapOfStringBigDecimals(String key);

    Property<Set<Integer>> setOfInts(String key);
    Property<Set<Long>> setOfLongs(String key);
    Property<Set<String>> setOfStrings(String key);
    Property<Set<Double>> setOfDoubles(String key);
    Property<Set<BigDecimal>> setOfBigDecimals(String key);
    Property<Set<LocalDate>> setOfLocalDates(String key);
    Property<Set<Pattern>> setOfPatterns(String key);

    Property<Duration> rangeValue(String key, Duration defaultValue, Range<Duration> boundaries);

    void analyze(URL url) throws Exception; // ~ offline

    String externalIp();

    default void putValueIfPresent(String key, ImmutableMap.Builder<String, String> map) {
        if (cfg().containsKey(key)) {
            String raw = Objects.requireNonNull(cfg().getString(key));
            map.put(key, raw);
        }
    }
    default void putValue(String key, ImmutableMap.Builder<String, String> map, String defaultValue) {
        if (cfg().containsKey(key)) {
            String raw = Objects.requireNonNull(cfg().getString(key));
            map.put(key, raw);
        } else {
            map.put(key, Objects.requireNonNull(defaultValue));
        }
    }
}
